@@ -244,14 +244,10 @@ def test_entry_from_qr_block_kev(qr_block_with_kev_unit):
     entry = DatabaseEntry._from_query_result_block(qr_block_with_kev_unit)
     assert entry.source == 'RHESSI'
     assert entry.provider == 'LSSP'
-    assert entry.fileid in ['/hessidata/2011/09/19/hsi_20110919_233340',
-                            '/hessidata/2011/09/20/hsi_20110920_010920']
-    assert entry.observation_time_start in [datetime(2011, 9, 20, 1, 9, 20),
-                                            datetime(2011, 9, 19, 23, 33, 40)]
-    assert entry.observation_time_end in [datetime(2011, 9, 20, 2, 27, 40),
-                                          datetime(2011, 9, 20, 1, 9, 20)]
+    assert entry.fileid == '/hessidata/2011/09/19/hsi_20110919_233340_002.fits'
+    assert entry.observation_time_start == datetime(2011, 9, 19, 23, 33, 40)
+    assert entry.observation_time_end == datetime(2011, 9, 20, 1, 9, 20)
     assert entry.instrument == 'RHESSI'
-    assert entry.size == -1
     assert round(entry.wavemin, 3) == 0.413
     assert round(entry.wavemax, 7) == 0.0000729
 
@@ -499,10 +495,60 @@ def test_entry_from_query_results_with_none_wave_and_default_unit(
             observation_time_start=datetime(1996, 4, 11, 0, 0),
             observation_time_end=datetime(2014, 3, 30, 23, 59),
             instrument='VIRGO', size=32652.0, wavemin=None,
-            wavemax=None)]
+            wavemax=None),
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/level1/1212/DIARAD/121222_1.D01',
+            observation_time_start=datetime(2012, 12, 24, 0, 1, 58),
+            observation_time_end=datetime(2012, 12, 25, 0, 1, 57),
+            instrument='VIRGO', size=14.0, wavemin=None,
+            wavemax=None),
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/tsi_full/VIRGO_TSI_hourly.dat.tar.gz',
+            observation_time_start=datetime(1995, 12, 2, 0, 0),
+            observation_time_end=datetime(2020, 1, 1, 0, 0),
+            instrument='VIRGO', size=3072.0, wavemin=None,
+            wavemax=None),
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/tsi_full/VIRGO_TSI_daily.dat.tar.gz',
+            observation_time_start=datetime(1995, 12, 2, 0, 0),
+            observation_time_end=datetime(2020, 1, 1, 0, 0),
+            instrument='VIRGO', size=140.0, wavemin=None,
+            wavemax=None),
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/spm/VIRGO-SPM-BLUE-L2-MISSIONLONG.fits',
+            observation_time_start=datetime(1996, 1, 23, 0, 0),
+            observation_time_end=datetime(2019, 9, 30, 23, 59),
+            instrument='VIRGO', size=32652.0, wavemin=None,
+            wavemax=None),
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/spm/VIRGO-SPM-GREEN-L2-MISSIONLONG.fits',
+            observation_time_start=datetime(1996, 1, 23, 0, 0),
+            observation_time_end=datetime(2019, 9, 30, 23, 59),
+            instrument='VIRGO', size=32652.0, wavemin=None,
+            wavemax=None),
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/spm/VIRGO-SPM-RED-L2-MISSIONLONG.fits',
+            observation_time_start=datetime(1996, 1, 23, 0, 0),
+            observation_time_end=datetime(2019, 9, 30, 23, 59),
+            instrument='VIRGO', size=32652.0, wavemin=None,
+            wavemax=None),
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/sph/VIRGO_D4.2_SPH_960411_120914.tar.gz',
+            observation_time_start=datetime(1996, 4, 11, 0, 0),
+            observation_time_end=datetime(2012, 9, 14, 0, 0),
+            instrument='VIRGO', size=512000.0, wavemin=None,
+            wavemax=None)
+    ]
 
-    for e in expected:
-        assert e in entries
+    for e in entries:
+        assert e in expected
 
 
 def test_create_display_table_missing_entries():
