@@ -3,14 +3,16 @@ from __future__ import absolute_import, division, print_function
 import os
 import glob
 from collections import OrderedDict
+import warnings
 
 import numpy as np
 import astropy.io.fits
+from astropy.wcs import WCS
 
-import sunpy
 from sunpy.map.mapbase import GenericMap, MAP_CLASSES
 from sunpy.map.compositemap import CompositeMap
 from sunpy.map.mapcube import MapCube
+from sunpy.map.mapsequence import MapSequence
 
 from sunpy.io.file_tools import read_file
 from sunpy.io.header import FileHeader
@@ -19,6 +21,7 @@ from sunpy.util.net import download_file
 from sunpy.util import expand_list
 from sunpy.util.metadata import MetaDict
 from sunpy.util.config import get_and_create_download_dir
+from sunpy.util.exceptions import SunpyDeprecationWarning
 
 from sunpy.util.datatype_factory_base import BasicRegistrationFactory
 from sunpy.util.datatype_factory_base import NoMatchError
@@ -28,6 +31,13 @@ from sunpy.extern import six
 
 from sunpy.extern.six.moves.urllib.request import urlopen
 
+SUPPORTED_ARRAY_TYPES = (np.ndarray,)
+try:
+    import dask.array
+    SUPPORTED_ARRAY_TYPES += (dask.array.Array,)
+except ImportError:
+    pass
+
 __authors__ = ["Russell Hewett, Stuart Mumford"]
 __email__ = "stuart@mumford.me.uk"
 
@@ -53,6 +63,7 @@ class MapFactory(BasicRegistrationFactory):
     Examples
     --------
     >>> import sunpy.map
+    >>> from astropy.io import fits
     >>> import sunpy.data.sample  # doctest: +REMOTE_DATA
     >>> mymap = sunpy.map.Map(sunpy.data.sample.AIA_171_IMAGE)  # doctest: +REMOTE_DATA
 
@@ -69,6 +80,20 @@ class MapFactory(BasicRegistrationFactory):
 
     >>> mymap = sunpy.map.Map(data, header)   # doctest: +SKIP
 
+    * data, wcs object, in tuple
+
+    >>> from astropy.wcs import WCS
+    >>> wcs = WCS(sunpy.data.sample.AIA_171_IMAGE)     # doctest: +REMOTE_DATA
+    >>> data = fits.getdata(sunpy.data.sample.AIA_171_IMAGE)    # doctest: +REMOTE_DATA
+    >>> mymap = sunpy.map.Map((data, wcs))    # doctest: +REMOTE_DATA
+
+    * data, wcs object, not in tuple
+
+    >>> from astropy.wcs import WCS
+    >>> wcs = WCS(sunpy.data.sample.AIA_171_IMAGE)     # doctest: +REMOTE_DATA
+    >>> data = fits.getdata(sunpy.data.sample.AIA_171_IMAGE)    # doctest: +REMOTE_DATA
+    >>> mymap = sunpy.map.Map(data, wcs)   # doctest: +REMOTE_DATA
+
     * File names
 
     >>> mymap = sunpy.map.Map('file1.fits')   # doctest: +SKIP
@@ -98,6 +123,7 @@ class MapFactory(BasicRegistrationFactory):
     >>> mymap = sunpy.map.Map((data, header), data2, header2, 'file1.fits', url_str, 'eit_*.fits')  # doctest: +SKIP
     """
 
+
     def _read_file(self, fname, **kwargs):
         """ Read in a file name and return the list of (data, meta) pairs in
             that file. """
@@ -134,6 +160,8 @@ class MapFactory(BasicRegistrationFactory):
         mixture of the following entries:
         * tuples of data,header
         * data, header not in a tuple
+        * data, wcs object in a tuple
+        * data, wcs object not in a tuple
         * filename, which will be read
         * directory, from which all files will be read
         * glob, from which all files will be read
@@ -163,22 +191,16 @@ class MapFactory(BasicRegistrationFactory):
 
             arg = args[i]
 
-            # Data-header pair in a tuple
-            if ((type(arg) in [tuple, list]) and
-                len(arg) == 2 and
-                isinstance(arg[0], np.ndarray) and
-                self._validate_meta(arg[1])):
+            # Data-header or data-WCS pair
+            if isinstance(arg, SUPPORTED_ARRAY_TYPES):
+                arg_header = args[i+1]
+                if isinstance(arg_header, WCS):
+                    arg_header = args[i+1].to_header()
 
-                arg[1] = OrderedDict(arg[1])
-                data_header_pairs.append(arg)
-
-            # Data-header pair not in a tuple
-            elif (isinstance(arg, np.ndarray) and
-                  self._validate_meta(args[i+1])):
-
-                pair = (args[i], OrderedDict(args[i+1]))
-                data_header_pairs.append(pair)
-                i += 1   # an extra increment to account for the data-header pairing
+                if self._validate_meta(arg_header):
+                    pair = (args[i], OrderedDict(arg_header))
+                    data_header_pairs.append(pair)
+                    i += 1    # an extra increment to account for the data-header pairing
 
             # File name
             elif (isinstance(arg, six.string_types) and
@@ -221,6 +243,7 @@ class MapFactory(BasicRegistrationFactory):
                 raise ValueError("File not found or invalid input")
 
             i += 1
+
         # TODO:
         # In the end, if there are already maps it should be put in the same
         # order as the input, currently they are not.
@@ -237,15 +260,20 @@ class MapFactory(BasicRegistrationFactory):
 
         Parameters
         ----------
-
         composite : boolean, optional
-            Indicates if collection of maps should be returned as a CompositeMap
+            Indicates if collection of maps should be returned as a CompositeMap.
+            Default is ``False``.
 
         cube : boolean, optional
             Indicates if collection of maps should be returned as a MapCube
 
+        sequence : boolean, optional
+            Indicates if collection of maps should be returned as a MapSequence.
+            Default is ``False``.
+
         silence_errors : boolean, optional
             If set, ignore data-header pairs which cause an exception.
+            Default is ``False``.
 
         Notes
         -----
@@ -255,7 +283,15 @@ class MapFactory(BasicRegistrationFactory):
 
         # Hack to get around Python 2.x not backporting PEP 3102.
         composite = kwargs.pop('composite', False)
+
+        # MapCube Deprecation
         cube = kwargs.pop('cube', False)
+        if cube:
+            warnings.warn('MapCube is now deprecated and renamed MapSequence. ' +
+                          'Please use the syntax Map(sequence=True) instead of Map(cube=True).',
+                          SunpyDeprecationWarning, stacklevel=2)
+
+        sequence = kwargs.pop('sequence', False)
         silence_errors = kwargs.pop('silence_errors', False)
 
         data_header_pairs, already_maps = self._parse_args(*args, **kwargs)
@@ -282,7 +318,14 @@ class MapFactory(BasicRegistrationFactory):
 
         # If the list is meant to be a cube, instantiate a map cube
         if cube:
-            return MapCube(new_maps, **kwargs)
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore", category=SunpyDeprecationWarning)
+                amapcube = MapCube(new_maps, **kwargs)
+            return amapcube
+
+        # If the list is meant to be a sequence, instantiate a map sequence
+        if sequence:
+            return MapSequence(new_maps, **kwargs)
 
         # If the list is meant to be a composite map, instantiate one
         if composite:
