@@ -17,6 +17,7 @@ from matplotlib import patches, cm, colors
 
 import astropy.wcs
 import astropy.units as u
+from astropy.io import fits
 from astropy.visualization.wcsaxes import WCSAxes
 from astropy.coordinates import SkyCoord, UnitSphericalRepresentation
 
@@ -118,16 +119,19 @@ class GenericMap(NDData):
     Scale:			 [2.402792 2.402792] arcsec / pix
     Reference Pixel:	 [512.5 512.5] pix
     Reference Coord:	 [3.22309951 1.38578135] arcsec
-    <BLANKLINE>
-    array([[ -96.,    7.,   -2., ..., -128., -128., -128.],
-           [ -97.,   -5.,    0., ...,  -99., -104., -128.],
-           [ -94.,    1.,   -4., ...,   -5.,  -38., -128.],
+    array([[ -95.92475  ,    7.076416 ,   -1.9656711, ..., -127.96519  ,
+            -127.96519  , -127.96519  ],
+           [ -96.97533  ,   -5.1167884,    0.       , ...,  -98.924576 ,
+            -104.04137  , -127.919716 ],
+           [ -93.99607  ,    1.0189276,   -4.0757103, ...,   -5.094638 ,
+             -37.95505  , -127.87541  ],
            ...,
-           [-128., -128., -128., ..., -128., -128., -128.],
-           [-128., -128., -128., ..., -128., -128., -128.],
-           [-128., -128., -128., ..., -128., -128., -128.]], dtype=float32)
-
-
+           [-128.01454  , -128.01454  , -128.01454  , ..., -128.01454  ,
+            -128.01454  , -128.01454  ],
+           [-127.899666 , -127.899666 , -127.899666 , ..., -127.899666 ,
+            -127.899666 , -127.899666 ],
+           [-128.03072  , -128.03072  , -128.03072  , ..., -128.03072  ,
+            -128.03072  , -128.03072  ]], dtype=float32)
 
     >>> aia.spatial_units   # doctest: +REMOTE_DATA
     SpatialPair(axis1=Unit("arcsec"), axis2=Unit("arcsec"))
@@ -647,14 +651,16 @@ class GenericMap(NDData):
         heliographic_longitude = self.meta.get('hgln_obs', None)
 
         if heliographic_longitude is None:
-            if self._default_heliographic_longitude is None:
-                warnings.warn_explicit(
-                    "Missing metadata for heliographic longitude: "
-                    "assuming longitude of 0 degrees",
-                    Warning, __file__,
-                    inspect.currentframe().f_back.f_lineno)
-                self._default_heliographic_longitude = 0
-            heliographic_longitude = self._default_heliographic_longitude
+            if self.meta.get('crln_obs', None) is not None:
+                heliographic_longitude = self.meta['crln_obs'] * u.deg - get_sun_L0(self.date)
+            else:
+                if self._default_heliographic_longitude is None:
+                    warnings.warn_explicit("Missing metadata for heliographic longitude: "
+                                           "assuming longitude of 0 degrees",
+                                           Warning, __file__,
+                                           inspect.currentframe().f_back.f_lineno)
+                    self._default_heliographic_longitude = 0
+                heliographic_longitude = self._default_heliographic_longitude
 
         if isinstance(heliographic_longitude, six.string_types):
             heliographic_longitude = float(heliographic_longitude)
@@ -752,6 +758,13 @@ class GenericMap(NDData):
         return np.matrix([[np.cos(p), -1 * lam * np.sin(p)],
                           [1/lam * np.sin(p), np.cos(p)]])
 
+    @property
+    def fits_header(self):
+        """
+        A `~astropy.io.fits.Header` representation of the ``meta`` attribute.
+        """
+        return sunpy.io.fits.header_to_fits(self.meta)
+
 # #### Miscellaneous #### #
 
     def _fix_date(self):
@@ -927,6 +940,12 @@ class GenericMap(NDData):
 
         filetype : str
             'auto' or any supported file extension.
+
+        Keywords
+        --------
+        hdu_type: `None`, `~fits.CompImageHDU`
+            `None` will return a normal FITS files.
+            `~fits.CompImageHDU` will rice compress the FITS file.
         """
         io.write_file(filepath, self.data, self.meta, filetype=filetype,
                       **kwargs)
@@ -1250,14 +1269,19 @@ class GenericMap(NDData):
         Scale:			 [2.402792 2.402792] arcsec / pix
         Reference Pixel:	 [127.5 126.5] pix
         Reference Coord:	 [3.22309951 1.38578135] arcsec
-        <BLANKLINE>
-        array([[ 451.,  566.,  586., ..., 1179., 1005.,  978.],
-               [ 475.,  515.,  556., ..., 1026., 1011., 1009.],
-               [ 547.,  621.,  621., ...,  935., 1074., 1108.],
-               ...,
-               [ 203.,  195.,  226., ...,  612.,  580.,  561.],
-               [ 207.,  213.,  233., ...,  651.,  622.,  537.],
-               [ 230.,  236.,  222., ...,  516.,  586.,  591.]], dtype=float32)
+        array([[ 450.4546 ,  565.81494,  585.0416 , ..., 1178.3234 , 1005.28284,
+                977.8161 ],
+            [ 474.20004,  516.1865 ,  555.7032 , ..., 1024.9636 , 1010.1449 ,
+                1010.1449 ],
+            [ 548.1609 ,  620.9256 ,  620.9256 , ...,  933.8139 , 1074.4924 ,
+                1108.4492 ],
+                ...,
+            [ 203.58617,  195.52335,  225.75891, ...,  612.7742 ,  580.52295,
+                560.3659 ],
+            [ 206.00058,  212.1806 ,  232.78065, ...,  650.96185,  622.12177,
+                537.6615 ],
+            [ 229.32516,  236.07002,  222.5803 , ...,  517.1058 ,  586.8026 ,
+                591.2992 ]], dtype=float32)
 
         >>> aia.submap([0,0]*u.pixel, [5,5]*u.pixel)   # doctest: +REMOTE_DATA
         SunPy Map
@@ -1274,13 +1298,16 @@ class GenericMap(NDData):
         Scale:			 [2.402792 2.402792] arcsec / pix
         Reference Pixel:	 [512.5 512.5] pix
         Reference Coord:	 [3.22309951 1.38578135] arcsec
-        <BLANKLINE>
-        array([[-96.,   7.,  -2.,  -3.,  -1.],
-               [-97.,  -5.,   0.,   0.,   1.],
-               [-94.,   1.,  -4.,   2.,  -2.],
-               [-97.,  -8.,  -3.,  -5.,  -1.],
-               [-96.,   6.,  -5.,  -1.,  -4.]], dtype=float32)
-
+        array([[-95.92475   ,   7.076416  ,  -1.9656711 ,  -2.9485066 ,
+                -0.98283553],
+            [-96.97533   ,  -5.1167884 ,   0.        ,   0.        ,
+                0.9746264 ],
+            [-93.99607   ,   1.0189276 ,  -4.0757103 ,   2.0378551 ,
+                -2.0378551 ],
+            [-96.97533   ,  -8.040668  ,  -2.9238791 ,  -5.1167884 ,
+                -0.9746264 ],
+            [-95.92475   ,   6.028058  ,  -4.9797    ,  -1.0483578 ,
+                -3.9313421 ]], dtype=float32)
         """
 
         if isinstance(bottom_left, (astropy.coordinates.SkyCoord,
