@@ -6,12 +6,12 @@ __author__ = "Keith Hughitt"
 __email__ = "keith.hughitt@nasa.gov"
 
 import numpy as np
+import matplotlib.pyplot as plt
 
 from astropy.visualization import PowerStretch
 from astropy.visualization.mpl_normalize import ImageNormalize
 
 from sunpy.map import GenericMap
-from sunpy.cm import cm
 from sunpy.map.sources.source_type import source_stretch
 
 __all__ = ['EUVIMap', 'CORMap', 'HIMap']
@@ -36,7 +36,7 @@ class EUVIMap(GenericMap):
 
         GenericMap.__init__(self, data, header, **kwargs)
         self._nickname = "{0}-{1}".format(self.detector, self.observatory[-1])
-        self.plot_settings['cmap'] = cm.get_cmap('sohoeit{wl:d}'.format(wl=int(self.wavelength.value)))
+        self.plot_settings['cmap'] = plt.get_cmap('sohoeit{wl:d}'.format(wl=int(self.wavelength.value)))
         self.plot_settings['norm'] = ImageNormalize(stretch=source_stretch(self.meta, PowerStretch(0.25)))
         self.meta['waveunit'] = 'Angstrom'
 
@@ -86,7 +86,7 @@ class CORMap(GenericMap):
         GenericMap.__init__(self, data, header, **kwargs)
 
         self._nickname = "{0}-{1}".format(self.detector, self.observatory[-1])
-        self.plot_settings['cmap'] = cm.get_cmap('stereocor{det!s}'.format(det=self.detector[-1]))
+        self.plot_settings['cmap'] = plt.get_cmap('stereocor{det!s}'.format(det=self.detector[-1]))
         self.plot_settings['norm'] = ImageNormalize(stretch=source_stretch(self.meta, PowerStretch(0.5)))
 
         # Try to identify when the FITS meta data does not have the correct
@@ -105,7 +105,7 @@ class CORMap(GenericMap):
     @classmethod
     def is_datasource_for(cls, data, header, **kwargs):
         """Determines if header corresponds to an COR image"""
-        return header.get('detector', '').startswith('COR')
+        return str(header.get('detector', '')).startswith('COR')
 
 
 class HIMap(GenericMap):
@@ -130,7 +130,7 @@ class HIMap(GenericMap):
 
         GenericMap.__init__(self, data, header, **kwargs)
         self._nickname = "{0}-{1}".format(self.detector, self.observatory[-1])
-        self.plot_settings['cmap'] = cm.get_cmap('stereohi{det!s}'.format(det=self.detector[-1]))
+        self.plot_settings['cmap'] = plt.get_cmap('stereohi{det!s}'.format(det=self.detector[-1]))
         self.plot_settings['norm'] = ImageNormalize(stretch=source_stretch(self.meta, PowerStretch(0.25)))
 
         # Try to identify when the FITS meta data does not have the correct
@@ -149,4 +149,4 @@ class HIMap(GenericMap):
     @classmethod
     def is_datasource_for(cls, data, header, **kwargs):
         """Determines if header corresponds to an COR image"""
-        return header.get('detector', '').startswith('HI')
+        return str(header.get('detector', '')).startswith('HI')
