@@ -60,8 +60,8 @@ class TimeSeriesFactory(BasicRegistrationFactory):
     Examples
     --------
     >>> import sunpy.timeseries
-    >>> import sunpy.data.sample
-    >>> my_timeseries = sunpy.timeseries.TimeSeries(sunpy.data.sample.GOES_XRS_TIMESERIES)
+    >>> import sunpy.data.sample  # doctest: +REMOTE_DATA
+    >>> my_timeseries = sunpy.timeseries.TimeSeries(sunpy.data.sample.GOES_XRS_TIMESERIES)  # doctest: +REMOTE_DATA
 
     The SunPy TimeSeries factory accepts a wide variety of inputs for creating time series
 
@@ -264,9 +264,6 @@ class TimeSeriesFactory(BasicRegistrationFactory):
         already_timeseries = list()
         filepaths = list()
 
-        # Take source kwarg if defined
-        source = kwargs.get('source', None)
-
         # Account for nested lists of items. Simply outputs a single list of
         # items, nested lists are expanded to element level.
         args = expand_list(args)
@@ -277,8 +274,7 @@ class TimeSeriesFactory(BasicRegistrationFactory):
             arg = args[i]
 
             # Data-header pair in a tuple
-            if (isinstance(arg, (np.ndarray, Table, pd.DataFrame))):
-                # and self._validate_meta(args[i+1])):
+            if isinstance(arg, (np.ndarray, Table, pd.DataFrame)):
                 # Assume a Pandas Dataframe is given
                 data = arg
                 units = OrderedDict()
@@ -286,7 +282,7 @@ class TimeSeriesFactory(BasicRegistrationFactory):
 
                 # Convert the data argument into a Pandas DataFrame if needed.
                 if isinstance(data, Table):
-                    # We have an AstroPy Table:
+                    # We have an Astropy Table:
                     data, meta, units = self._from_table(data)
                 elif isinstance(data, np.ndarray):
                     # We have a numpy ndarray. We assume the first column is a dt index
@@ -294,7 +290,7 @@ class TimeSeriesFactory(BasicRegistrationFactory):
 
                 # If there are 1 or 2 more arguments:
                 for _ in range(2):
-                    if (len(args) > i+1):
+                    if len(args) > i+1:
                         # If that next argument isn't data but is metaddata or units:
                         if not isinstance(args[i+1], (np.ndarray, Table, pd.DataFrame)):
                             if self._validate_units(args[i+1]):
@@ -316,13 +312,8 @@ class TimeSeriesFactory(BasicRegistrationFactory):
                   os.path.isfile(os.path.expanduser(arg))):
 
                 path = os.path.expanduser(arg)
-
-                read, result = self._read_file(path, **kwargs)
-
-                if read:
-                    data_header_pairs.append(result)
-                else:
-                    filepaths.append(result)
+                result = self._read_file(path, **kwargs)
+                data_header_pairs, filepaths = _apply_result(data_header_pairs, filepaths, result)
 
             # Directory
             elif (isinstance(arg, six.string_types) and
@@ -333,11 +324,9 @@ class TimeSeriesFactory(BasicRegistrationFactory):
                 for afile in files:
                     # returns a boolean telling us if it were read and either a
                     # tuple or the original filepath for reading by a source
-                    read, result = self._read_file(afile, **kwargs)
-                    if read:
-                        data_header_pairs.append(result)
-                    else:
-                        filepaths.append(result)
+                    result = self._read_file(afile, **kwargs)
+                    data_header_pairs, filepaths = _apply_result(data_header_pairs, filepaths,
+                                                                 result)
 
             # Glob
             elif (isinstance(arg, six.string_types) and '*' in arg):
@@ -348,11 +337,9 @@ class TimeSeriesFactory(BasicRegistrationFactory):
                     # data_header_unit_tuples += self._read_file(afile, **kwargs)
                     # returns a boolean telling us if it were read and either a
                     # tuple or the original filepath for reading by a source
-                    read, result = self._read_file(afile, **kwargs)
-                    if read:
-                        data_header_pairs.append(result)
-                    else:
-                        filepaths.append(result)
+                    result = self._read_file(afile, **kwargs)
+                    data_header_pairs, filepaths = _apply_result(data_header_pairs, filepaths,
+                                                                 result)
 
             # Already a TimeSeries
             elif isinstance(arg, GenericTimeSeries):
@@ -363,12 +350,9 @@ class TimeSeriesFactory(BasicRegistrationFactory):
                   _is_url(arg)):
                 url = arg
                 path = download_file(url, get_and_create_download_dir())
-                pairs = self._read_file(path, **kwargs)
-                # data_header_pairs += pairs
-                filepaths.append(pairs[1])
-
+                result = self._read_file(path, **kwargs)
+                data_header_pairs, filepaths = _apply_result(data_header_pairs, filepaths, result)
             else:
-                # raise ValueError("File not found or invalid input")
                 raise NoMatchError("File not found or invalid input")
             i += 1
 
@@ -410,14 +394,13 @@ class TimeSeriesFactory(BasicRegistrationFactory):
         for filepath in filepaths:
             try:
                 new_ts = self._check_registered_widgets(filepath=filepath, **kwargs)
+                new_timeseries.append(new_ts)
             except (NoMatchError, MultipleMatchError, ValidationFunctionError):
                 if not silence_errors:
                     raise
             except:
                 raise
 
-            new_timeseries.append(new_ts)
-
         # data_header_pairs is a list of HDUs as read by sunpy.io
         # For each set of HDus find the matching class and read the
         # data_header_unit_tuples by calling the _parse_hdus method
@@ -464,14 +447,13 @@ class TimeSeriesFactory(BasicRegistrationFactory):
             try:
                 new_ts = self._check_registered_widgets(data=data, meta=meta,
                                                         units=units, **kwargs)
+                new_timeseries.append(new_ts)
             except (NoMatchError, MultipleMatchError, ValidationFunctionError):
                 if not silence_errors:
                     raise
             except:
                 raise
 
-            new_timeseries.append(new_ts)
-
         new_timeseries += already_timeseries
 
         # Concatenate the timeseries into one if specified.
@@ -539,6 +521,16 @@ class TimeSeriesFactory(BasicRegistrationFactory):
         return WidgetType(data, meta, units, **kwargs)
 
 
+def _apply_result(data_header_pairs, filepaths, result):
+    read, result = result
+    if read:
+        data_header_pairs.append(result)
+    else:
+        filepaths.append(result)
+
+    return data_header_pairs, filepaths
+
+
 def _is_url(arg):
     try:
         urlopen(arg)
